# The PIL.ImageFilter Module

BLUR (class) [#]

  Blur filter.

  For more information about this class, see The BLUR Class.

CONTOUR (class) [#]

  Contour filter.

  For more information about this class, see The CONTOUR Class.

DETAIL (class) [#]

  Detail filter.

  For more information about this class, see The DETAIL Class.

EDGE_ENHANCE (class) [#]

  Edge enhancement filter.

  For more information about this class, see The EDGE_ENHANCE Class.

EDGE_ENHANCE_MORE (class) [#]

  Stronger edge enhancement filter.

  For more information about this class, see The EDGE_ENHANCE_MORE Class.

EMBOSS (class) [#]

  Embossing filter.

  For more information about this class, see The EMBOSS Class.

FIND_EDGES (class) [#]

  Edge-finding filter.

  For more information about this class, see The FIND_EDGES Class.

Kernel(size, kernel, **options) (class) [#]

  Convolution filter kernel.

  For more information about this class, see The Kernel Class.

MaxFilter(size=3) (class) [#]

  Max filter.

  For more information about this class, see The MaxFilter Class.

MedianFilter(size=3) (class) [#]

  Median filter.

  For more information about this class, see The MedianFilter Class.

MinFilter(size=3) (class) [#]

  Min filter.

  For more information about this class, see The MinFilter Class.

ModeFilter(size=3) (class) [#]

  Mode filter.

  For more information about this class, see The ModeFilter Class.

RankFilter(size, rank) (class) [#]

  Rank filter.

  For more information about this class, see The RankFilter Class.

SHARPEN (class) [#]

  Sharpening filter.

  For more information about this class, see The SHARPEN Class.

SMOOTH (class) [#]

  Smoothing filter.

  For more information about this class, see The SMOOTH Class.

SMOOTH_MORE (class) [#]

  Stronger smoothing filter.

  For more information about this class, see The SMOOTH_MORE Class.

## The BLUR Class

BLUR (class) [#]

## The CONTOUR Class

CONTOUR (class) [#]

## The DETAIL Class

DETAIL (class) [#]

## The EDGE_ENHANCE Class

EDGE_ENHANCE (class) [#]

## The EDGE_ENHANCE_MORE Class

EDGE_ENHANCE_MORE (class) [#]

## The EMBOSS Class

EMBOSS (class) [#]

## The FIND_EDGES Class

FIND_EDGES (class) [#]

## The Kernel Class

Kernel(size, kernel, **options) (class) [#]
__init__(size, kernel, **options) [#]

  Create a convolution kernel. The current version only supports 3x3 and 5x5 integer and floating point kernels.

  In the current version, kernels can only be applied to "L" and "RGB" images.

  size
  kernel
  **options
  scale=
  offset=

## The MaxFilter Class

MaxFilter(size=3) (class) [#]
__init__(size=3) [#]
  size

## The MedianFilter Class

MedianFilter(size=3) (class) [#]
__init__(size=3) [#]
  size

## The MinFilter Class

MinFilter(size=3) (class) [#]
__init__(size=3) [#]
  size

## The ModeFilter Class

ModeFilter(size=3) (class) [#]
__init__(size=3) [#]
  size

## The RankFilter Class

RankFilter(size, rank) (class) [#]
__init__(size, rank) [#]
  size
  rank

## The SHARPEN Class

SHARPEN (class) [#]

## The SMOOTH Class

SMOOTH (class) [#]

## The SMOOTH_MORE Class

SMOOTH_MORE (class) [#]